Package: RMySQL
Version: 0.11.1
Title: Database Interface and 'MySQL' Driver for R
Description: Legacy 'DBI' interface to 'MySQL' / 'MariaDB' based on old code
    ported from S-PLUS. A modern 'MySQL' client written in 'C++' is available
    from the 'RMariaDB' package.
Authors@R: c(person("Jeroen", "Ooms", email = "jeroenooms@gmail.com", 
      role = c("aut", "cre"), comment = c(ORCID = "0000-0002-4035-0289")),
    person("David", "James", role = "aut"),
    person("Saikat", "DebRoy", role = "aut"),
    person("Hadley", "Wickham", email = "hadley@rstudio.com", role = "aut"),
    person("Jeffrey", "Horner", role = "aut"),
    person("RStudio", role = "cph"))
Depends: R (>= 2.8.0), DBI (>= 0.4)
Imports: methods
License: GPL-2
URL: https://r-dbi.r-universe.dev/RMySQL
        https://downloads.mariadb.org/connector-c/
BugReports: https://github.com/r-dbi/rmysql/issues
SystemRequirements: libmariadb-client-dev | libmariadb-client-lgpl-dev
        | libmysqlclient-dev (deb), mariadb-devel (rpm), mariadb |
        mysql-connector-c (brew), mysql56_dev (csw)
NeedsCompilation: yes
Collate: 'mysql.R' 'driver.R' 'connection.R' 'data-type.R' 'default.R'
        'escaping.R' 'result.R' 'extension.R' 'is-valid.R' 'table.R'
        'transaction.R'
Suggests: testthat, curl
RoxygenNote: 7.3.2.9000
Packaged: 2025-04-01 13:02:47 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (<https://orcid.org/0000-0002-4035-0289>),
  David James [aut],
  Saikat DebRoy [aut],
  Hadley Wickham [aut],
  Jeffrey Horner [aut],
  RStudio [cph]
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2025-04-01 13:40:02 UTC
Built: R 4.4.0; amd64-portbld-midnightbsd4.0.2; 2026-02-17 22:21:35 UTC; unix
