# Generated by roxygen2: do not edit by hand

export(CLIENT_COMPRESS)
export(CLIENT_CONNECT_WITH_DB)
export(CLIENT_FOUND_ROWS)
export(CLIENT_IGNORE_SIGPIPE)
export(CLIENT_IGNORE_SPACE)
export(CLIENT_INTERACTIVE)
export(CLIENT_LOCAL_FILES)
export(CLIENT_LONG_FLAG)
export(CLIENT_LONG_PASSWORD)
export(CLIENT_MULTI_RESULTS)
export(CLIENT_MULTI_STATEMENTS)
export(CLIENT_NO_SCHEMA)
export(CLIENT_ODBC)
export(CLIENT_PROTOCOL_41)
export(CLIENT_RESERVED)
export(CLIENT_SECURE_CONNECTION)
export(CLIENT_SSL)
export(CLIENT_TRANSACTIONS)
export(MySQL)
export(dbApply)
export(dbEscapeStrings)
export(dbMoreResults)
export(dbNextResult)
export(isIdCurrent)
export(mysqlBuildTableDefinition)
export(mysqlClientLibraryVersions)
export(mysqlHasDefault)
exportClasses(MySQLConnection)
exportClasses(MySQLDriver)
exportClasses(MySQLResult)
exportMethods(SQLKeywords)
exportMethods(dbApply)
exportMethods(dbBegin)
exportMethods(dbClearResult)
exportMethods(dbColumnInfo)
exportMethods(dbCommit)
exportMethods(dbConnect)
exportMethods(dbDataType)
exportMethods(dbDisconnect)
exportMethods(dbEscapeStrings)
exportMethods(dbExistsTable)
exportMethods(dbFetch)
exportMethods(dbGetException)
exportMethods(dbGetInfo)
exportMethods(dbGetRowCount)
exportMethods(dbGetRowsAffected)
exportMethods(dbGetStatement)
exportMethods(dbHasCompleted)
exportMethods(dbIsValid)
exportMethods(dbListConnections)
exportMethods(dbListFields)
exportMethods(dbListResults)
exportMethods(dbListTables)
exportMethods(dbMoreResults)
exportMethods(dbNextResult)
exportMethods(dbQuoteIdentifier)
exportMethods(dbReadTable)
exportMethods(dbRemoveTable)
exportMethods(dbRollback)
exportMethods(dbSendQuery)
exportMethods(dbUnloadDriver)
exportMethods(dbWriteTable)
exportMethods(fetch)
exportMethods(isSQLKeyword)
exportMethods(make.db.names)
exportMethods(show)
exportMethods(summary)
import(DBI)
import(methods)
importFrom(utils,packageVersion)
importFrom(utils,read.table)
importFrom(utils,write.table)
useDynLib(RMySQL)
useDynLib(RMySQL,RS_MySQL_cloneConnection)
useDynLib(RMySQL,RS_MySQL_closeConnection)
useDynLib(RMySQL,RS_MySQL_closeResultSet)
useDynLib(RMySQL,RS_MySQL_connectionInfo)
useDynLib(RMySQL,RS_MySQL_dbApply)
useDynLib(RMySQL,RS_MySQL_exec)
useDynLib(RMySQL,RS_MySQL_fetch)
useDynLib(RMySQL,RS_MySQL_moreResultSets)
useDynLib(RMySQL,RS_MySQL_newConnection)
useDynLib(RMySQL,RS_MySQL_nextResultSet)
useDynLib(RMySQL,RS_MySQL_resultSetInfo)
useDynLib(RMySQL,rmysql_connection_valid)
useDynLib(RMySQL,rmysql_driver_close)
useDynLib(RMySQL,rmysql_driver_info)
useDynLib(RMySQL,rmysql_driver_init)
useDynLib(RMySQL,rmysql_driver_valid)
useDynLib(RMySQL,rmysql_escape_strings)
useDynLib(RMySQL,rmysql_exception_info)
useDynLib(RMySQL,rmysql_fields_info)
useDynLib(RMySQL,rmysql_result_valid)
useDynLib(RMySQL,rmysql_version)
