% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/connection.R
\docType{class}
\name{MySQLConnection-class}
\alias{MySQLConnection-class}
\title{Class MySQLConnection.}
\description{
\code{MySQLConnection.} objects are usually created by
\code{\link[DBI]{dbConnect}}
}
\keyword{internal}
