% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mysql.R
\name{constants}
\alias{constants}
\alias{.MySQLPkgName}
\alias{.MySQLPkgVersion}
\alias{.MySQLPkgRCS}
\alias{.MySQLSQLKeywords}
\alias{CLIENT_LONG_PASSWORD}
\alias{CLIENT_FOUND_ROWS}
\alias{CLIENT_LONG_FLAG}
\alias{CLIENT_CONNECT_WITH_DB}
\alias{CLIENT_NO_SCHEMA}
\alias{CLIENT_COMPRESS}
\alias{CLIENT_ODBC}
\alias{CLIENT_LOCAL_FILES}
\alias{CLIENT_IGNORE_SPACE}
\alias{CLIENT_PROTOCOL_41}
\alias{CLIENT_INTERACTIVE}
\alias{CLIENT_SSL}
\alias{CLIENT_IGNORE_SIGPIPE}
\alias{CLIENT_TRANSACTIONS}
\alias{CLIENT_RESERVED}
\alias{CLIENT_SECURE_CONNECTION}
\alias{CLIENT_MULTI_STATEMENTS}
\alias{CLIENT_MULTI_RESULTS}
\title{Constants}
\description{
Constants
}
\section{Constants}{
 \code{.MySQLPkgName} (currently \code{"RMySQL"}),
\code{.MySQLPkgVersion} (the R package version), \code{.MySQLPkgRCS} (the
RCS revision), \code{.MySQLSQLKeywords} (a lot!)
}

